@@ -70,17 +70,29 @@ class Page(NotionObject):
         self.load_mark('properties')
 
     @property
-    def parent(self):
-        return self['parent']
+    def string_title(self) -> str:
+        for k, v in self['properties'].items():
+            if v['id'] == 'title':
+                return ''.join([t['plain_text'] for t in v['title']])
+        return self.id
 
     @property
-    def properties(self):
+    def parent(self) -> Parent:
+        return self['parent']
+
+
+    @property
+    def properties(self) -> Properties:
         return self['properties']
 
     @property
     def object(self):
         return self['object']
 
+    @property
+    def short_id(self):
+        return self.id[:4]
+
     @property
     def id(self):
         return self['id']
